import request from '@/utils/request'

export function add(data) {
  return request({
    url: 'api/asnDetail',
    method: 'post',
    data
  })
}
export function getIdData(ids) {
  return request({
    url: 'api/asnDetail/getIdData',
    method: 'post',
    data:ids
  })
}
export function rkAndQxButton(data) {
  return request({
    url: 'api/asnDetail/rkAndQxButton',
    method: 'post',
    data
  })
}
export function rkAndQxButtonQX(data) {
  return request({
    url: 'api/asnDetail/rkAndQxButtonQX',
    method: 'post',
    data
  })
}
export function cancelPut(data) {
  return request({
    url: 'api/asnDetail/cancelPut',
    method: 'post',
    data
  })
}

export function queryAsnDetailAll(data) {
  return request({
    url: 'api/asnDetail/queryAsnDetailAll',
    method: 'get',
    data
  })
}

export function del(ids) {
  return request({
    url: 'api/asnDetail/',
    method: 'delete',
    data: ids
  })
}

export function edit(data) {
  return request({
    url: 'api/asnDetail',
    method: 'put',
    data
  })
}
//修改容器
export function updateContainer(data) {
  return request({
    url: 'api/asnDetail/updateContainer'+"?stockId="+data.id,
    method: 'put',
    data:data.data
  })
}

export function doCheckAsn(ids) {
  return request({
    url: 'api/asnDetail/checkAsn',
    method: 'put',
    data:ids
  })
}

export function putawayAsn(ids) {
  return request({
    url: 'api/asnDetail/putawayAsn',
    method: 'post',
    data:ids
  })
}

export function putawayConfirm(data) {
  return request({
    url: 'api/asnDetail/putawayConfirmXpp',
    method: 'post',
    data
  })
}

export function collectPutAway(data) {
  return request({
    url: 'api/asnDetail/collectPutAway',
    method: 'post',
    data
  })
}

export function collectMOCreate(data) {
  return request({
    url: 'api/asnDetail/createMoInfo',
    method: 'post',
    data
  })
}





export default { add, del,edit,doCheckAsn,collectMOCreate,updateContainer,queryAsnDetailAll,putawayConfirm,rkAndQxButtonQX,cancelPut,collectPutAway}
